/*
 * Copyright (C) 2008 The Android Open Source Project
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.dianxinos.launcher2.dxwidget;

import android.widget.RemoteViews;
import android.content.ComponentName;

interface IDXWidgetService {
    /**
     * 将RemoteViews更新到appWidgetId所对应的widget上
     *
     * @param appWidgetId
     * @param views
     */
    void updateAppWidget(int appWidgetId, in RemoteViews views);

    /**
     * 将RemoteViews更新到provider所对应的widget上
     * <p>
     * @param {@link DXWidgetProvider}的ComponentName对象
     * @param views
     */
    void updateAppWidgetProvider(in ComponentName provider, in RemoteViews views);

    /**
     * 将RemoteViews更新到provider和appWidgetId所对应的widget上
     *
     * @param provider
     * @param appWidgetId
     * @param views
     */
    void updateAppWidgetByPkgAndId(in ComponentName provider, int appWidgetId, in RemoteViews views);

    /**
     * 获得provider对应所有DXWidget ID数组
     * <p>
     * @param {@link DXWidgetProvider}的ComponentName对象
     */
    int[] getAppWidgetIds(in ComponentName provider);

    /**
    * 获得服务器端的版本信息
    */
    int getServerVersionCode();
    String getServerVersion();

    void updateAppWidgetIds(in int[] appWidgetId, in RemoteViews views);
    int getAppWidgetHostId();
}
